#!/bin/bash

#
# Perform a backup (a bash script in $backup_jobs_dir)
#

#---------------------------------------------------------------
source /opt/bashfun/interactive.sh
source /opt/bashfun/misc.sh

#
# $1 - dir where backup jobs are stored
# Job files are in a special format - see ...?
#
listJobs()
{
    local jobs
    local item
    
    jobs=`oneEndSlash ${backup_jobs_dir}`*
    for job in ${jobs[@]}
    do
        item=`getJobNumber $job`' - '`describeJob $job`
        echo "$item"
    done
    return 0
}
getJobNumber()
{
    local jobfile="$1"
    echo `basename $job` | sed s,.sh,,
}
describeJob()
{
    local jobfile="$1"
    cat $jobfile | grep '# DESCRIPTION' | sed s,'# DESCRIPTION: ',,
    echo
}
help()
{
    cat <<EOF

(*) show available jobs:

    \$ gentool backup list

(*) perform a backup job:
    
    \$ gentool backup \$i
    
EOF
}

sanityChecks()
{
    if [ ! -d $backup_jobs_dir ]
    then
        mkdir -vp $backup_jobs_dir
    fi

    if [ `haveJobs` -eq 0 ]
    then
        echo 'no backup jobs are defined in ['${backup_jobs_dir}']'
        exit 0
    fi
}

haveJobs()
{
    local x=0
    local job

    jobs=`oneEndSlash ${backup_jobs_dir}`*
    for job in ${jobs[@]}
    do
        if [ ! "$job" = "$jobs" ]
        then
            x=1
        fi
    done
    echo $x
}

#---------------------------------------------------------------

backup_jobs_dir=~/.gentool/backup-jobs/
requested_job=${backup_jobs_dir}${2}'.sh'

sanityChecks

if [ $# -eq 1 ]
then
    
    listJobs
    exit 0
fi

if [ "$2" = 'list' ]
then
    listJobs
    exit 0
fi

if [ ! -f "$requested_job" ]
then
    listJobs "$backup_jobs_dir"
    exit 0
fi

describeJob $requested_job
bash $requested_job $@
exit $?
